==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebGroupByKeyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByKeyDescription } from "./WebGroupByKeyDescription";
/**
 * @hidden
 */
export let WebGroupByKeyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupByKeyDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupByKeyDescriptionMetadata.a == null) {
                WebGroupByKeyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupByKeyDescriptionMetadata.c(WebGroupByKeyDescriptionMetadata.a);
            }
            if (a.k(WebGroupByKeyDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGroupByKeyDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GroupByKey");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("FieldName", "String");
            a.item("Value", "Unknown");
        }
        static d(a) {
            WebGroupByKeyDescriptionMetadata.b(a);
            a.ad("WebGroupByKey", () => new WebGroupByKeyDescription());
            a.ac("WebGroupByKey", WebGroupByKeyDescriptionMetadata.a);
        }
    }
    WebGroupByKeyDescriptionMetadata.$t = markType(WebGroupByKeyDescriptionMetadata, 'WebGroupByKeyDescriptionMetadata');
    WebGroupByKeyDescriptionMetadata.a = null;
    return WebGroupByKeyDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebGroupByKeyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByKeyDescription } from "./WebGroupByKeyDescription";
/**
 * @hidden
 */
export let WebGroupByKeyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupByKeyDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupByKeyDescriptionMetadata.a == null) {
                WebGroupByKeyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupByKeyDescriptionMetadata.c(WebGroupByKeyDescriptionMetadata.a);
            }
            if (a.k(WebGroupByKeyDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGroupByKeyDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GroupByKey");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("FieldName", "String");
            a.item("Value", "Unknown");
        }
        static d(a) {
            WebGroupByKeyDescriptionMetadata.b(a);
            a.ae("WebGroupByKey", () => new WebGroupByKeyDescription());
            a.ad("WebGroupByKey", WebGroupByKeyDescriptionMetadata.a);
        }
    }
    WebGroupByKeyDescriptionMetadata.$t = markType(WebGroupByKeyDescriptionMetadata, 'WebGroupByKeyDescriptionMetadata');
    WebGroupByKeyDescriptionMetadata.a = null;
    return WebGroupByKeyDescriptionMetadata;
})();
